==> haskell-hasql-1.1.1-56-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.1.1
id: hasql-1.1.1-222qfNailiP756CsCrpOQm
key: hasql-1.1.1-222qfNailiP756CsCrpOQm
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
    .
    The version 1 is completely backward-compatible with 0.19.
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
abi: ffa5e13773cc4a93db205c7d23a46cbf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-1.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hasql-1.1.1
hs-libraries: HShasql-1.1.1-222qfNailiP756CsCrpOQm
depends:
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    postgresql-binary-0.12.1-FLafPGOVnMzE52fQvZzdbg
    postgresql-libpq-0.9.3.1-8jMYZXnIAmTBsSVRHWMv1l
    bytestring-strict-builder-0.4.5-c0px6CSJH4Ezim2P3v6Ho
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    hashtables-1.2.3.0-7TdqUBBYHAbAAjykzazpkH
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    profunctors-5.2.2-tLOt4dPZZiLCnuqjAhdY2
    contravariant-extras-0.3.4-JUsruK2M2q178GgFofBYvf
    contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
    placeholders-0.1-7BdB7sfQOem1gBmR2N4Uyl
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             postgresql-binary-0.12.1-FLafPGOVnMzE52fQvZzdbg=4a8f19013225ef1ceefdb112aae5fb16
             postgresql-libpq-0.9.3.1-8jMYZXnIAmTBsSVRHWMv1l=248bcaf6e7689c6576b892596ad23a47
             bytestring-strict-builder-0.4.5-c0px6CSJH4Ezim2P3v6Ho=cda2a79000d01161b1159f3dcdfd8dff
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             hashtables-1.2.3.0-7TdqUBBYHAbAAjykzazpkH=32a405226bbbbccf15e0a3785c334a72
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             profunctors-5.2.2-tLOt4dPZZiLCnuqjAhdY2=20f9843906eb1a5fcfc2baccf1835360
             contravariant-extras-0.3.4-JUsruK2M2q178GgFofBYvf=358ac830ec277a1de95ff9226a8ca243
             contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr=5e2c57f6d5adae18dd0e94f3a1c17f3b
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ=6ebcb425d9bd801b8232e32e531b7de0
             placeholders-0.1-7BdB7sfQOem1gBmR2N4Uyl=a565c254eaaf778ca845d18a4aad88e0
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.1.1-64-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.1.1
id: hasql-1.1.1-BIt3EkrDrCeGDmeZcFPDFA
key: hasql-1.1.1-BIt3EkrDrCeGDmeZcFPDFA
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
    .
    The version 1 is completely backward-compatible with 0.19.
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
abi: a7d390e2b12939ccde8009afbfbf5a64
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-1.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hasql-1.1.1
hs-libraries: HShasql-1.1.1-BIt3EkrDrCeGDmeZcFPDFA
depends:
    attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv
    postgresql-binary-0.12.1-EKLmuBk3Xu7JG6LcTDZMRN
    postgresql-libpq-0.9.3.1-8jMYZXnIAmTBsSVRHWMv1l
    bytestring-strict-builder-0.4.5-6Fn8jn4JhhoqBAzDl4Y9V
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    hashtables-1.2.3.0-7TdqUBBYHAbAAjykzazpkH
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5
    profunctors-5.2.2-5deYtNXgJL0Ee5ERglnepT
    contravariant-extras-0.3.4-8L6I2XQwII1IEPShYVbxe2
    contravariant-1.4.1-CaIS0FAz3wNFYESTGhl5v6
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
    placeholders-0.1-7BdB7sfQOem1gBmR2N4Uyl
    base-prelude-1.2.1-9DojpA5E5OtH7FZzMevW8v base-4.10.1.0
abi-depends: attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv=7ed301843f5485a15f31657e67db1a15
             postgresql-binary-0.12.1-EKLmuBk3Xu7JG6LcTDZMRN=b3fce7c9983c99300e1623c9bd8a65d4
             postgresql-libpq-0.9.3.1-8jMYZXnIAmTBsSVRHWMv1l=248bcaf6e7689c6576b892596ad23a47
             bytestring-strict-builder-0.4.5-6Fn8jn4JhhoqBAzDl4Y9V=90b66ba119b1af32a973da0bb413fd21
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             hashtables-1.2.3.0-7TdqUBBYHAbAAjykzazpkH=32a405226bbbbccf15e0a3785c334a72
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             data-default-class-0.1.2.0-ImBMrJK18PFLLtssITDnZ5=59d0190781dd74e9cf2161eb5998f2f1
             profunctors-5.2.2-5deYtNXgJL0Ee5ERglnepT=2ee65ebbde2cecfbb7094181d600e1a2
             contravariant-extras-0.3.4-8L6I2XQwII1IEPShYVbxe2=7e9a0f8c2b16cca46759c083c027a6bd
             contravariant-1.4.1-CaIS0FAz3wNFYESTGhl5v6=6a3c34b34c4bd5d9276d1724f3d09ec8
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ=6ebcb425d9bd801b8232e32e531b7de0
             placeholders-0.1-7BdB7sfQOem1gBmR2N4Uyl=a565c254eaaf778ca845d18a4aad88e0
             base-prelude-1.2.1-9DojpA5E5OtH7FZzMevW8v=4a6c49e31ccaae1a3e4ac7975d1ab849
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
